@@ -7,21 +7,34 @@
 #ifndef PLASMA_ABSTRACTRUNNER_H
 #define PLASMA_ABSTRACTRUNNER_H
 
-#include <QIcon>
+#include "krunner_export.h"
+
 #include <QObject>
 #include <QStringList>
 
+#if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 94)
 #include <KConfigGroup>
-#include <KPluginInfo>
+#include <QIcon>
+#else
+class KConfigGroup;
+class QIcon;
+#endif
 #include <KPluginMetaData>
-#include <KService>
 
+#if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 91)
+#include <KPluginInfo>
+#include <KService>
+#else
+#include <KPluginFactory>
+#endif
+
+#if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 65)
 #include <plasma/plasma_export.h> // for PLASMA_ENABLE_DEPRECATED_SINCE
 #include <plasma_version.h>
+#endif
 
 #include <memory>
 
-#include "krunner_export.h"
 #include "querymatch.h"
 #include "runnercontext.h"
 #include "runnersyntax.h"
@@ -66,7 +79,7 @@ class KRUNNER_EXPORT AbstractRunner : public QObject
 public:
 #if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 81)
     /** Specifies a nominal speed for the runner */
-    enum Speed {
+    enum Speed{
         SlowSpeed,
         NormalSpeed,
     };
@@ -628,6 +641,22 @@ protected:
     void setDefaultSyntax(const RunnerSyntax &syntax);
 #endif
 
+    /**
+     * Utility overload for creating a syntax based on the given parameters
+     * @see RunnerSyntax
+     * @since 5.106
+     */
+    inline void addSyntax(const QString &exampleQuery, const QString &description)
+    {
+        addSyntax(QStringList(exampleQuery), description);
+    }
+
+    /// @copydoc addSyntax(const QString &exampleQuery, const QString &description)
+    inline void addSyntax(const QStringList &exampleQueries, const QString &description)
+    {
+        addSyntax(RunnerSyntax(exampleQueries, description));
+    }
+
     /**
      * Sets the list of syntaxes; passing in an empty list effectively clears
      * the syntaxes.
@@ -678,8 +707,8 @@ protected:
 
 private:
     std::unique_ptr<AbstractRunnerPrivate> const d;
-    bool hasUniqueResults();
-    bool hasWeakResults();
+    KRUNNER_NO_EXPORT bool hasUniqueResults();
+    KRUNNER_NO_EXPORT bool hasWeakResults();
     friend class RunnerContext;
     friend class RunnerContextPrivate;
     friend class QueryMatch;
@@ -740,4 +769,12 @@ K_PLUGIN_FACTORY(ConfigFactory, registerPlugin<classname>();)
 #endif
 // clang-format on
 
+#if !KRUNNER_ENABLE_DEPRECATED_SINCE(5, 91)
+namespace KRunner
+{
+using AbstractRunner = Plasma::AbstractRunner;
+using RunnerContext = Plasma::RunnerContext;
+}
+#endif
+
 #endif
